@@ -21,11 +21,12 @@ modelCarrots.sas <- lme4::lmer(Preference ~
                                                Age = "contr.SAS"))
 
 ## here an error produces
-tools::assertError(stopifnot(all.equal(logLik(modelCarrots.treat), 
-                                       logLik(modelCarrots.sas))))
-
-tools::assertError(stopifnot(all.equal(VarCorr(modelCarrots.treat), 
-                                       VarCorr(modelCarrots.sas), tol = 1e-5)))
+## NO MORE in lme4 1.1-8
+# tools::assertError(stopifnot(all.equal(logLik(modelCarrots.treat), 
+#                                        logLik(modelCarrots.sas))))
+# 
+# tools::assertError(stopifnot(all.equal(VarCorr(modelCarrots.treat), 
+#                                        VarCorr(modelCarrots.sas), tol = 1e-5)))
 
 
                               
@@ -49,7 +50,7 @@ modelHam.treat <- lmer(Informed.liking ~
 
 stopifnot(all.equal(logLik(modelHam.sas), logLik(modelHam.treat)))
 stopifnot(all.equal(VarCorr(modelHam.sas), VarCorr(modelHam.treat), 
-                    tol = 1e-6))
+                    tol = 1e-3))
 
 ## check that lsmeans is the same whether the contrasts for the models are differenr
 lmer4 <- lmer(increase ~ treat + (1|block), data = tree,  
@@ -58,5 +59,5 @@ lmer4 <- lmer(increase ~ treat + (1|block), data = tree,
 lmer5 <- lmer(increase ~ treat+ (1|block), data = tree,  
               contrasts = list(treat = "contr.SAS"))
 
-all.equal(lsmeans(lmer4), lsmeans(lmer5))
+all.equal(lsmeans(lmer4), lsmeans(lmer5), tol = 1e-3)
 
